@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from wexample_wex_core.workdir.code_base_workdir import CodeBaseWorkdir
+from wexample_wex_addon_app.workdir.code_base_workdir import CodeBaseWorkdir
 
 
 class JavascriptWorkdir(CodeBaseWorkdir):
